Run config
------------

Settings for how to run zfit.

.. autosummary::
    :toctree: _generated/run

    zfit.run.set_graph_mode
    zfit.run.set_autograd_mode
    zfit.run.clear_graph_cache
    zfit.run.executing_eagerly
    zfit.run.assert_executing_eagerly
    zfit.run.set_n_cpu
    zfit.run.set_cpus_explicitly


Settings
-----------------

General settings for zfit

.. automodule:: zfit.settings
    :members:
